/**
  *  \file int/export/exphtml.cc
  *
  *  (c) 2001-2019 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "int/export/exphtml.h"
#include "cpluslib/utf8.h"
#include "cpluslib/format.h"
#include "io/textfile.h"
#include "int/value.h"

IntHtmlTextExporter::IntHtmlTextExporter(TextFile& tf)
    : tf(tf)
{ }

void
IntHtmlTextExporter::startTable(const IntExportFieldList& fields, const TIntTypeHint /*types*/[])
{
    tf.writeLine("<!DOCTYPE html>");
    tf.writeLine("<html>");
    tf.writeLine(" <head>");
    tf.writeLine("  <title>PCC2 export</title>");
    tf.writeLine(" </head>");
    tf.writeLine(" <body>");
    tf.writeLine("  <table>");
    tf.writeLine("   <tr>");
    for (IntExportFieldList::index_t i = 0, n = fields.size(); i < n; ++i) {
        writeTag("th", fields.getFieldName(i));
    }
    tf.writeLine("   </tr>");
}

void
IntHtmlTextExporter::startRecord()
{
    tf.writeLine("   <tr>");
}

void
IntHtmlTextExporter::addField(IntValue* value, const string_t& /*name*/, TIntTypeHint /*type*/)
{
    writeTag("td", IntValue::toStringOf(value, false));
}

void
IntHtmlTextExporter::endRecord()
{
    tf.writeLine("   </tr>");
}

void
IntHtmlTextExporter::endTable()
{
    tf.writeLine("  </table>");
    tf.writeLine(" </body>");
    tf.writeLine("</html>");
}

void
IntHtmlTextExporter::writeTag(const char* tagName, const string_t& content)
{
    string_t escaped;
    Utf8Reader rdr(content.data(), content.size());
    while (rdr.hasMore()) {
        uint32_t ch = rdr.get();
        if (ch == '&') {
            escaped.append("&amp;");
        } else if (ch == '<') {
            escaped.append("&lt;");
        } else if (ch == '>') {
            escaped.append("&gt;");
        } else if (ch <= 127) {
            escaped.append(1, char(ch));
        } else {
            escaped.append(format("&#%d;", ch));
        }
    }
    tf.writeLine(format("    <%s>%s</%0$s>", tagName, escaped));
}
