/**
  *  \file u/t_util_atom.cc
  *
  *  (c) 2001-2019 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "util/atom.h"
#include "u/t_util.h"

void
UtilAtomTestSuite::testHash()
{
    TS_ASSERT_EQUALS(strHash("foo"), strHash("foo", 3));
    TS_ASSERT_EQUALS(strHash("foo"), strHash(string_t("foo")));
}

void
UtilAtomTestSuite::testAtom()
{
    // atom table must be empty
    atomClear();
    TS_ASSERT(!isAtom(NULL_ATOM));
    TS_ASSERT(!isAtom(ATOM_LOWER_BOUND));

    TS_ASSERT(!atomNC("foo"));
    TS_ASSERT(!atomNC("bar"));

    // now add some atoms
    atom_t foo = atom("foo");
    atom_t bar = atom("bar");
    TS_ASSERT(isAtom(foo));
    TS_ASSERT(isAtom(bar));
    TS_ASSERT_DIFFERS(foo, bar);
    TS_ASSERT_EQUALS(atom("foo"), foo);
    TS_ASSERT_EQUALS(atom("bar"), bar);
    TS_ASSERT_EQUALS(atomStr(foo), "foo");
    TS_ASSERT_EQUALS(atomStr(bar), "bar");
    TS_ASSERT_EQUALS(atomNC("foo"), foo);
    TS_ASSERT_DIFFERS(atom("FOO"), foo);
}
